@@ -543,6 +543,13 @@ module API
           type: String,
           desc: 'The Mattermost token'
         }
+      ],
+      'slack-slash-commands' => [
+        {
+          name: :token,
+          type: String,
+          desc: 'The Slack token'
+        }
       ]
     }.freeze
 
@@ -612,6 +619,14 @@ module API
     end
 
     trigger_services.each do |service_slug, settings|
+      helpers do
+        def chat_command_service(project, service_slug, params)
+          project.services.active.where(template: false).find do |service|
+            service.try(:token) == params[:token] && service.to_param == service_slug.underscore
+          end
+        end
+      end
+
       params do
         requires :id, type: String, desc: 'The ID of a project'
       end
@@ -630,9 +645,8 @@ module API
           # This is not accurate, but done to prevent leakage of the project names
           not_found!('Service') unless project
 
-          service = project.find_or_initialize_service(service_slug.underscore)
-
-          result = service.try(:active?) && service.try(:trigger, params)
+          service = chat_command_service(project, service_slug, params)
+          result = service.try(:trigger, params)
 
           if result
             status result[:status] || 200
