@@ -371,23 +371,25 @@ describe 'Issues', feature: true do
 
   describe 'when I want to reset my incoming email token' do
     let(:project1) { create(:project, namespace: @user.namespace) }
-    let(:issue) { create(:issue, project: project1) }
+    let!(:issue) { create(:issue, project: project1) }
 
     before do
-      allow(Gitlab.config.incoming_email).to receive(:enabled).and_return(true)
+      stub_incoming_email_setting(enabled: true, address: "p+%{key}@gl.ab")
       project1.team << [@user, :master]
-      project1.issues << issue
       visit namespace_project_issues_path(@user.namespace, project1)
     end
 
     it 'changes incoming email address token', js: true do
       find('.issue-email-modal-btn').click
       previous_token = find('input#issue_email').value
-
       find('.incoming-email-token-reset').click
-      wait_for_ajax
 
-      expect(find('input#issue_email').value).not_to eq(previous_token)
+      expect(page).to have_no_field('issue_email', with: previous_token)
+      new_token = project1.new_issue_address(@user.reload)
+      expect(page).to have_field(
+        'issue_email',
+        with: new_token
+      )
     end
   end
 
@@ -617,14 +619,18 @@ describe 'Issues', feature: true do
       end
 
       it 'adds due date to issue' do
+        date = Date.today.at_beginning_of_month + 2.days
+
         page.within '.due_date' do
           click_link 'Edit'
 
           page.within '.ui-datepicker-calendar' do
-            first('.ui-state-default').click
+            click_link date.day
           end
 
-          expect(page).to have_no_content 'None'
+          wait_for_ajax
+
+          expect(find('.value').text).to have_content date.strftime('%b %-d, %Y')
         end
       end
 
@@ -636,6 +642,8 @@ describe 'Issues', feature: true do
             first('.ui-state-default').click
           end
 
+          wait_for_ajax
+
           expect(page).to have_no_content 'No due date'
 
           click_link 'remove due date'
