@@ -11,21 +11,22 @@
 /*= require project */
 
 (function() {
-  window.gon || (window.gon = {});
-
-  window.gon.api_version = 'v3';
-
   describe('Project Title', function() {
-    fixture.preload('project_title.html');
-    fixture.preload('projects.json');
+    preloadFixtures('static/project_title.html.raw');
     beforeEach(function() {
-      fixture.load('project_title.html');
+      loadFixtures('static/project_title.html.raw');
+
+      window.gon = {};
+      window.gon.api_version = 'v3';
+
       return this.project = new Project();
     });
-    return describe('project list', function() {
+
+    describe('project list', function() {
       var fakeAjaxResponse = function fakeAjaxResponse(req) {
         var d;
         expect(req.url).toBe('/api/v3/projects.json?simple=true');
+        expect(req.data).toEqual({ search: '', order_by: 'last_activity_at', per_page: 20 });
         d = $.Deferred();
         d.resolve(this.projects_data);
         return d.promise();
@@ -33,7 +34,7 @@
 
       beforeEach((function(_this) {
         return function() {
-          _this.projects_data = fixture.load('projects.json')[0];
+          _this.projects_data = getJSONFixture('projects.json');
           return spyOn(jQuery, 'ajax').and.callFake(fakeAjaxResponse.bind(_this));
         };
       })(this));
@@ -48,6 +49,10 @@
         return expect($('.header-content').hasClass('open')).toBe(false);
       });
     });
+
+    afterEach(() => {
+      window.gon = {};
+    });
   });
 
 }).call(this);
