@@ -175,7 +175,7 @@ describe CommitStatus, models: true do
     end
 
     it 'returns statuses without what we want to ignore' do
-      is_expected.to eq(statuses.values_at(1, 2, 4, 5, 6, 8, 9))
+      is_expected.to eq(statuses.values_at(0, 1, 2, 3, 4, 5, 6, 8, 9))
     end
   end
 
@@ -200,49 +200,6 @@ describe CommitStatus, models: true do
     end
   end
 
-  describe '#stages' do
-    before do
-      create :commit_status, pipeline: pipeline, stage: 'build', name: 'linux', stage_idx: 0, status: 'success'
-      create :commit_status, pipeline: pipeline, stage: 'build', name: 'mac', stage_idx: 0, status: 'failed'
-      create :commit_status, pipeline: pipeline, stage: 'deploy', name: 'staging', stage_idx: 2, status: 'running'
-      create :commit_status, pipeline: pipeline, stage: 'test', name: 'rspec', stage_idx: 1, status: 'success'
-    end
-
-    context 'stages list' do
-      subject { CommitStatus.where(pipeline: pipeline).stages }
-
-      it 'returns ordered list of stages' do
-        is_expected.to eq(%w[build test deploy])
-      end
-    end
-
-    context 'stages with statuses' do
-      subject { CommitStatus.where(pipeline: pipeline).latest.stages_status }
-
-      it 'returns list of stages with statuses' do
-        is_expected.to eq({
-          'build' => 'failed',
-          'test' => 'success',
-          'deploy' => 'running'
-        })
-      end
-
-      context 'when build is retried' do
-        before do
-          create :commit_status, pipeline: pipeline, stage: 'build', name: 'mac', stage_idx: 0, status: 'success'
-        end
-
-        it 'ignores a previous state' do
-          is_expected.to eq({
-            'build' => 'success',
-            'test' => 'success',
-            'deploy' => 'running'
-          })
-        end
-      end
-    end
-  end
-
   describe '#commit' do
     it 'returns commit pipeline has been created for' do
       expect(commit_status.commit).to eq project.commit
@@ -277,4 +234,32 @@ describe CommitStatus, models: true do
       end
     end
   end
+
+  describe '#detailed_status' do
+    let(:user) { create(:user) }
+
+    it 'returns a detailed status' do
+      expect(commit_status.detailed_status(user))
+        .to be_a Gitlab::Ci::Status::Success
+    end
+  end
+
+  describe '#sortable_name' do
+    tests = {
+      'karma' => ['karma'],
+      'karma 0 20' => ['karma ', 0, ' ', 20],
+      'karma 10 20' => ['karma ', 10, ' ', 20],
+      'karma 50:100' => ['karma ', 50, ':', 100],
+      'karma 1.10' => ['karma ', 1, '.', 10],
+      'karma 1.5.1' => ['karma ', 1, '.', 5, '.', 1],
+      'karma 1 a' => ['karma ', 1, ' a']
+    }
+
+    tests.each do |name, sortable_name|
+      it "'#{name}' sorts as '#{sortable_name}'" do
+        commit_status.name = name
+        expect(commit_status.sortable_name).to eq(sortable_name)
+      end
+    end
+  end
 end
